Feature Store Client
====================

Feature Store is used to manage and provide easy access for curated features. The goal is to abstract the underlying storage of the features and also provide a consistent and unified storage for the features meta-data. The features should be versioned so data scientist can be sure that the model trained on specific combination of features will always lead to the same results.

Feature Store Client provides a simple, high-level API for integrating Python environments with H2O.ai's Feature Store. 
 
